@@ -52,7 +52,7 @@ static int version = 0;		/* If 1, print only program name and version */
 static int setgnoise = 0;	/* If 1, pixels have been set to random noise */
 static int addgnoise = 0;	/* If 1, pixels have random noise added */
 
-static char *RevMsg = "CONPIX WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "CONPIX WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
