@@ -37,7 +37,7 @@
 #define MAXFILES	2000
 #define MAXLINES	100000
 
-static char *RevMsg = "GETCOL WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "GETCOL WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 static void usage();
 static int ListFile();
