@@ -66,7 +66,7 @@
 #define MST	3
 #define LST	4
 
-static char *RevMsg = "GETDATE WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "GETDATE WCSTools 3.8.7, 31 October 2012, Jessica Mink SAO";
 
 static void usage();
 static void ConvertDate();
