@@ -1,9 +1,9 @@
 /* File gethead.c
- * December 14, 2011
+ * August 10, 2012
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2011
+   Copyright (C) 1996-2012
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -47,7 +47,7 @@ extern char *GetFITShead();
 static char nextnsp();
 static int PrintValues();
 
-static char *RevMsg = "GETHEAD WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETHEAD WCSTools 3.8.7, 19 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int nfile = 0;
@@ -1111,7 +1111,7 @@ char	*kwd[];		/* Names of keywords for which to print values */
 			if (!isnum (string))
 			    hgets (header, "RDEC", 80, string);
 			dec = str2dec (string);
-			fk425 (&ra, &dec);
+			fk425e (&ra, &dec, epoch);
 			ra2str (string, 80, ra, ncdec);
 			}
 		    else if (iepoch != 2000) {
@@ -1158,7 +1158,7 @@ char	*kwd[];		/* Names of keywords for which to print values */
 			if (!isnum (string))
 			    hgets (header, "RRA", 80, string);
 			ra = str2ra (string);
-			fk425 (&ra, &dec);
+			fk425e (&ra, &dec, epoch);
 			dec2str (string, 80, dec, ncdec);
 			}
 		    else if (iepoch != 2000) {
@@ -1444,4 +1444,6 @@ char *string;
  * Aug 12 2011	Fix range of extensions from -x
  * Aug 12 2011	Add prefixed range of extensions from -x
  * Dec 14 2011	If length of header/file content string is zero, exit with error
+ *
+ * Aug 10 2012	Call fk425e() instead of fk425()
  */
