@@ -36,7 +36,7 @@ static void usage();
 static void PrintPix();
 static void procpix();
 
-static char *RevMsg = "GETPIX WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "GETPIX WCSTools 3.8.7, 31 October 2012, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;		/* If 1, print only program name and version */
