@@ -37,7 +37,7 @@
 static void usage();
 static int ExtractImage();
 
-static char *RevMsg = "IMEXTRACT WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMEXTRACT WCSTools 3.8.7, 19 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose flag */
 static int krename = 0;
