@@ -37,7 +37,7 @@ static int StackImage();
 static int verbose = 0;		/* verbose flag */
 static int wfits = 1;		/* if 1, write FITS header before data */
 static char *newname = NULL;
-static char *RevMsg = "IMSTACK WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMSTACK WCSTools 3.8.7, 19 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static int nfiles = 0;
 static int nbstack = 0;
 static int extend = 0;		/* If 1, output multi-extension FITS file */
