@@ -1,5 +1,5 @@
 /*** File wcslib/imio.c
- *** April 12, 2012
+ *** October 19, 2012
  *** By Jessica Mink, jmink@cfa.harvard.edu
  *** Harvard-Smithsonian Center for Astrophysics
  *** Copyright (C) 1996-2012
@@ -20,8 +20,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
     Correspondence concerning WCSTools should be addressed as follows:
-           Internet email: dmink@cfa.harvard.edu
-           Postal address: Doug Mink
+           Internet email: jmink@cfa.harvard.edu
+           Postal address: Jessica Mink
                            Smithsonian Astrophysical Observatory
                            60 Garden St.
                            Cambridge, MA 02138 USA
@@ -661,10 +661,10 @@ int	npix;		/* Number of pixels to check */
     switch (bitpix) {
 
 	case 8:
-	    imc = (unsigned char *)(image + pix1);
-	    imaxc = *(im2+ipix);
+	    imc = (unsigned char *)(image);
+	    imaxc = *(imc + pix1);
 	    for (ipix = pix1; ipix < pix2; ipix++) {
-		ipc = *(image + ipix);
+		ipc = *(imc + ipix);
 		if (ipc > imaxc)
 		    imaxc = ipc;
 		}
@@ -764,10 +764,10 @@ int	npix;		/* Number of pixels to check */
     switch (bitpix) {
 
 	case 8:
-	    cmin = *(image + pix1);
 	    imc = (unsigned char *)image;
+	    cmin = *(imc + pix1);
 	    for (ipix = pix1; ipix < pix2; ipix++) {
-		cp = *(image + ipix);
+		cp = *(imc + ipix);
 		if (cp < cmin)
 		    cmin = cp;
 		}
@@ -777,12 +777,10 @@ int	npix;		/* Number of pixels to check */
 	case 16:
 	    im2 = (short *)image + pix1;
 	    imin2 = *im2;
-	    il2 = im2 + npix;
-	    ip2 = im2;
-	    while (ip2 < il2) {
+	    for (ipix = pix1; ipix < pix2; ipix++) {
+		ip2 = *(im2 + ipix);
 		if (*ip2 < imin2)
 		    imin2 = *ip2;
-		ip2++;
 		}
 	    dmin = (double) imin2;
 	    break;
@@ -1540,4 +1538,5 @@ imswapped ()
  * Jun 11 2007	Add minvec() and speed up maxvec()
  *
  * Apr 12 2012	Fix 8-bit variables to be unsigned char
+ * Oct 19 2012	Fix errors with character images in minvec() and maxvec()
  */
