@@ -1,7 +1,7 @@
 /*** File wcslib/zpxpos.c
  *** March 8, 2011
  *** By Frank Valdes, valdes@noao.edu
- *** Modified from tnxpos.c by Doug Mink, dmink@cfa.harvard.edu
+ *** Modified from tnxpos.c by Jessica Mink, jmink@cfa.harvard.edu
  *** Harvard-Smithsonian Center for Astrophysics
  *** After IRAF mwcs/wfzpx.x
  *** Copyright (C) 1998-2011
@@ -22,8 +22,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
     Correspondence concerning WCSTools should be addressed as follows:
-           Internet email: dmink@cfa.harvard.edu
-           Postal address: Doug Mink
+           Internet email: jmink@cfa.harvard.edu
+           Postal address: Jessica Mink
                            Smithsonian Astrophysical Observatory
                            60 Garden St.
                            Cambridge, MA 02138 USA
