@@ -36,7 +36,7 @@ static double matchrad = 5.0;	/* Initial match radius is 5 arcseconds */
 int version = 0;		/* If 1, print only program name and version */
 static void usage();
 
-static char *RevMsg = "MATCHCAT WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "MATCHCAT WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 main (ac, av)
 int ac;
