@@ -9,7 +9,7 @@
 #include "libned/ned_client.h"
 #include "libwcs/wcs.h"
 
-static char *RevMsg = "WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "WCSTools 3.8.7, 31 October 2012, Jessica Mink SAO";
 
 extern int ned_errno;
 static void PrintUsage();
