@@ -10,7 +10,7 @@
 #include "libwcs/wcs.h"
 #include "libwcs/fitsfile.h"
 
-static char *RevMsg = "NEDPOS 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "NEDPOS 3.8.7, 31 October 2012, Jessica Mink SAO";
 
 extern int ned_errno;
 static void PrintUsage();
