@@ -47,7 +47,7 @@ extern void setcdelt();
 extern void setproj();
 extern struct WorldCoor *GetFITSWCS();
 
-static char *RevMsg = "NEWFITS WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "NEWFITS WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 static int verbose = 0;	/* verbose/debugging flag */
 static int bitpix = 0;	/* number of bits per pixel (FITS code, 0=no image) */
 static int version = 0;	/* If 1, print only program name and version */
