@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 int
 main (ac, av)
