@@ -39,7 +39,7 @@ extern struct WorldCoor *GetWCSFITS ();	/* Read WCS from FITS or IRAF file */
 extern char *GetFITShead();
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "SKY2XY WCSTools 3.8.5, 12 April 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "SKY2XY WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
