@@ -1,5 +1,5 @@
 /* File sumpix.c
- * February 1, 2012
+ * May 16, 2012
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
@@ -36,16 +36,20 @@ static void usage();
 static void SumPix();
 extern double PhotPix();
 
-static char *RevMsg = "SUMPIX WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "SUMPIX WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;	/* If 1, print only program name and version */
 static int complim = 0;	/* If 1, compute limiting values over range */
 static int compsum = 0;	/* If 1, compute sum over range */
 static int compmean = 0;/* If 1, compute mean over range */
+static int compmed = 0;/* If 1, compute median over range */
 static int compvar = 0;	/* If 1, compute variance over range */
 static int compstd = 0;	/* If 1, compute standard deviation over range */
 static int compphot = 0; /* If 1, compute photometry in circular aperture */
+static int printindex = 0; /* If 1, print row and/or column */
+static int printhead = 0; /* If 1, print column headers for output values */
+static int printtab = 0; /* If 1, tab-separate values */
 static char *xstr;	/* X coordinate of center of aperture */
 static char *ystr;	/* Y coordinate of center of aperture */
 static double rad;	/* Radius of aperture in pixels */
@@ -99,6 +103,18 @@ char **av;
 		    compstd++;
 		    break;
 
+		case 'e':	/* Compute median */
+		    compmed++;
+		    break;
+
+		case 'h':	/* Print column headers for output values */
+		    printhead++;
+		    break;
+
+		case 'i':	/* Print index */
+		    printindex++;
+		    break;
+
 		case 'l':	/* Compute limits */
 		    complim++;
 		    break;
@@ -117,15 +133,24 @@ char **av;
 		case 'p':	/* Print filename at start of line */
 		    printfile++;
 		    break;
+
 		case 'r':	/* Compute variance */
 		    compvar++;
 		    break;
+
 		case 's':	/* Compute sum */
 		    compsum++;
 		    break;
+
+		case 't':	/* Tab-separate values */
+		    printtab++;
+		    printhead++;
+		    break;
+
 		case 'v':	/* more verbosity */
 		    verbose++;
 		    break;
+
 		default:
 		    usage();
 		    break;
@@ -138,8 +163,9 @@ char **av;
 		crange = *av;
 	    else {
 		rrange = *av;
-		if (fn != NULL)
+		if (fn != NULL) {
 		    SumPix (fn, crange, rrange);
+		    }
 		}
 	    }
 
@@ -177,15 +203,19 @@ usage ()
 	exit (-1);
     fprintf (stderr,"Sum row, column, or region of a FITS or IRAF image\n");
     fprintf(stderr,"Usage: sumpix [-dmrsv][-n num] x_range  y_range file.fit ...\n");
-    fprintf(stderr,"  -c x y r: compute total counts in circle r from (x,y)\n");
-    fprintf(stderr,"  -d: compute and print standard deviation\n");
-    fprintf(stderr,"  -l: compute and print min and max values\n");
-    fprintf(stderr,"  -m: compute and print mean\n");
-    fprintf(stderr,"  -n: number of decimal places in output\n");
+    fprintf(stderr,"  -c x y r: Compute total counts in circle r from (x,y)\n");
+    fprintf(stderr,"  -d: Compute and print standard deviation\n");
+    fprintf(stderr,"  -e: Compute and print median\n");
+    fprintf(stderr,"  -h: Print column headers for output values\n");
+    fprintf(stderr,"  -i: Print row or column number if other is 0\n");
+    fprintf(stderr,"  -l: Compute and print min and max values\n");
+    fprintf(stderr,"  -m: Compute and print mean\n");
+    fprintf(stderr,"  -n: Number of decimal places in output\n");
     fprintf(stderr,"  -p: Print file name at start of line\n");
-    fprintf(stderr,"  -r: compute and print variance (sum of squares)\n");
-    fprintf(stderr,"  -s: compute and print sum (default)\n");
-    fprintf(stderr,"  -v: verbose\n");
+    fprintf(stderr,"  -r: Compute and print variance (sum of squares)\n");
+    fprintf(stderr,"  -s: Compute and print sum (default)\n");
+    fprintf(stderr,"  -t: Separate output values with tabs and add column headers\n");
+    fprintf(stderr,"  -v: Verbose\n");
     fprintf(stderr,"  a range of 0 implies the full dimension\n");
     fprintf(stderr,"  an absence of ranges uses the entire image\n");
     exit (1);
@@ -209,6 +239,7 @@ char *rrange;	/* Row range string */
     double bscale;	/* Scale factor for pixel scaling */
     double counts;
     double wt;
+    double medpix();
     int iraffile;
     double dpix, sum;
     double ra, dec, xp, yp;
@@ -217,6 +248,7 @@ char *rrange;	/* Row range string */
     int offscl;
     int np;
     double dnp, mean, variance, std, sumsq, dmin, dmax;
+    double xmax, ymax, median, medpix();
     char pixname[256];
     char numform[8];
     char numforme[8];
@@ -278,11 +310,11 @@ char *rrange;	/* Row range string */
 	}
 
     if (ndec > -1) {
-	sprintf (numform, "%%.%df ", ndec);
+	sprintf (numform, "%%.%df", ndec);
 	sprintf (numforme, "%%.%df", ndec);
 	}
     else {
-	sprintf (numform, "%%.2f ");
+	sprintf (numform, "%%.2f");
 	sprintf (numforme, "%%.2f");
 	}
 
@@ -327,21 +359,23 @@ char *rrange;	/* Row range string */
     else if (!strcmp (crange, "0") && !strcmp (rrange, "0")) {
 	nx = xdim;
 	ny = ydim;
-	sum = 0.0;
-	sumsq = 0.0;
-	np = 0;
-	dmin = 1000000000000000.0;
-	dmax = -10000000000000000.0;
-	for (x = 0; x < nx; x++) {
-	    for (y = 0; y < ny; y++) {
-        	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
-		sum = sum + dpix;
-		sumsq = sumsq + (dpix * dpix);
-		if (dpix < dmin)
-		    dmin = dpix;
-		if (dpix > dmax)
-		    dmax = dpix;
-		np++;
+	if (compsum || complim) {
+	    sum = 0.0;
+	    sumsq = 0.0;
+	    np = 0;
+	    dmin = 1000000000000000.0;
+	    dmax = -10000000000000000.0;
+	    for (x = 0; x < nx; x++) {
+		for (y = 0; y < ny; y++) {
+     		    dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
+		    sum = sum + dpix;
+		    sumsq = sumsq + (dpix * dpix);
+		    if (dpix < dmin)
+			dmin = dpix;
+		    if (dpix > dmax)
+			dmax = dpix;
+		    np++;
+		    }
 		}
 	    }
 	dnp = (double) np;
@@ -371,6 +405,77 @@ char *rrange;	/* Row range string */
 	xrange = RangeInit (crange, xdim);
 	nx = rgetn (xrange);
 	ny = ydim;
+	xmax = xrange->valmax;
+	if (printhead) {
+	    if (printindex) {
+		printf ("i");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmed) {
+		printf ("median");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compsum) {
+		printf ("sum");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmean) {
+		printf ("mean");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compvar) {
+		printf ("var");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compstd) {
+		printf ("stdev");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (complim) {
+		printf ("min");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		printf ("max");
+		}
+	    printf ("\n");
+	    if (printtab) {
+		if (printindex) 
+		    printf ("-----	");
+		if (compmed)
+		    printf ("------	");
+		if (compsum)
+		    printf ("---	");
+		if (compmean)
+		    printf ("----	");
+		if (compvar)
+		    printf ("---	");
+	    	if (compstd)
+		    printf ("-----	");
+		if (complim)
+		    printf ("---	---");
+		printf ("\n");
+		}
+	    }
 	for (ix = 0; ix < nx; ix++) {
 	    x = rgeti4 (xrange) - 1;
 	    sum = 0.0;
@@ -389,22 +494,67 @@ char *rrange;	/* Row range string */
 		np++;
 		}
 	    dnp = (double) np;
-	    if (compsum)
+	    if (printindex) {
+		if (xmax < 10.0)
+		    printf ("%d", ix);
+		else if (xmax < 100.0)
+		    printf ("%2d", ix);
+		else if (xmax < 1000.0)
+		    printf ("%3d", ix);
+		else if (xmax < 10000.0)
+		    printf ("%4d", ix);
+		else
+		    printf ("%5d", ix);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmed) {
+		median = (double) medpix (image, 0.0, x, 1, nx, ny, nx, 1, bitpix);
+		printf (numform, median);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compsum) {
 		printf (numform, sum);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    mean = sum / dnp;
-	    if (compmean)
+	    if (compmean) {
 		printf (numform, mean);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    variance = sumsq;
-	    if (compvar)
+	    if (compvar) {
 		printf (numform, variance);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    if (compstd) {
 		std = sqrt ((sumsq / dnp) - (mean * mean));
 		printf (numforme, std);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
 		}
 	    if (complim) {
-		printf (" ");
 		printf (numform, dmin);
-		printf ("- ");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
 		printf (numform, dmax);
 		}
 	    printf ("\n");
@@ -417,8 +567,103 @@ char *rrange;	/* Row range string */
 	yrange = RangeInit (rrange, xdim);
 	ny = rgetn (yrange);
 	nx = xdim;
-	for (iy = 0; iy < ny; iy++) {
+	ymax = yrange->valmax;
+	if (printhead) {
+	    if (printindex) {
+		printf ("i");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmed) {
+		printf ("median");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compsum) {
+		printf ("sum");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmean) {
+		printf ("mean");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compvar) {
+		printf ("var");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compstd) {
+		printf ("stdev");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (complim) {
+		printf ("min");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		printf ("max");
+		}
+	    printf ("\n");
+	    if (printtab) {
+		if (printindex)
+		    printf ("-----	");
+		if (compmed)
+		    printf ("------	");
+		if (compsum)
+		    printf ("---	");
+		if (compmean)
+		    printf ("----	");
+		if (compvar)
+		    printf ("---	");
+		if (compstd)
+		    printf ("-----	");
+		if (complim)
+		    printf ("---	---");
+		printf ("\n");
+		}
+	    }
+	    for (iy = 0; iy < ny; iy++) {
 	    y = rgeti4 (yrange) - 1;
+	    if (printindex) {
+		if (ymax < 10.0)
+		    printf ("%d", iy);
+		else if (ymax < 100.0)
+		    printf ("%2d", iy);
+		else if (ymax < 1000.0)
+		    printf ("%3d", iy);
+		else if (ymax < 10000.0)
+		    printf ("%4d", iy);
+		else
+		    printf ("%5d", iy);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
+	    if (compmed) {
+		median = (double) medpix (image, 0.0, 1, y, nx, ny, nx, 1, bitpix);
+		printf (numform, median);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    sum = 0.0;
 	    sumsq = 0.0;
 	    dmin = 1000000000000000.0;
@@ -435,22 +680,44 @@ char *rrange;	/* Row range string */
 		np++;
 		}
 	    dnp = (double) np;
-	    if (compsum)
+	    if (compsum) {
 		printf (numform, sum);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    mean = sum / dnp;
-	    if (compmean)
+	    if (compmean) {
 		printf (numform, mean);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    variance = sumsq;
-	    if (compvar)
+	    if (compvar) {
 		printf (numform, variance);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
+		}
 	    if (compstd) {
 		std = sqrt ((sumsq / dnp) - (mean * mean));
 		printf (numforme, std);
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
 		}
 	    if (complim) {
 		printf (" ");
 		printf (numform, dmin);
-		printf ("- ");
+		if (printtab)
+		    printf ("\t");
+		else
+		    printf (" ");
 		printf (numform, dmax);
 		}
 	    printf ("\n");
@@ -517,14 +784,14 @@ char *rrange;	/* Row range string */
 /* Jul  2 1999	New program
  * Jul  6 1999	Fix bug with x computation in patch adding section
  * Oct 22 1999	Drop unused variables after lint
- * Oct 29 1999	Add option to compute and print mean, rms, std, and/or sum
+ * Oct 29 1999	Add option to compute and printf mean, rms, std, and/or sum
  * Dec 10 1999	Add option -n to set number of decimal places in output
  * Dec 14 1999	Change rms to variance
  *
  * Mar 23 2000	Use hgetm() to get the IRAF pixel file name, not hgets()
  *
  * Dec  6 2002	Add option to sum over entire image if both ranges are 0
- * Dec  6 2002	Add -l option to print range of values
+ * Dec  6 2002	Add -l option to printf range of values
  *
  * Jun 21 2006	Clean up code
  *
@@ -533,4 +800,7 @@ char *rrange;	/* Row range string */
  * Jan 11 2007	Add PhotPix to compute circular aperture photometry
  *
  * Feb  1 2012	Improve argument parsing so order doesn't matter
+ * May 16 2012	Add options i to print index and e to compute medians
+ * May 16 2012	Add option t to separate values by tabs
+ * May 16 2012	Add option h to print headings
  */
