@@ -24,7 +24,7 @@ static int hms = 0;		/* 1 for output in hh:mm:ss dd:mm:ss */
 static int nf = 0;
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "TESTROT WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "TESTROT WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 main (ac, av)
 int ac;
