@@ -47,7 +47,7 @@ static int restwave = 0;	/* If 1, print first dimension limits */
 static int printhead = 1;	/* 1 until header has been printed */
 static char *rootdir=NULL;	/* Root directory for input files */
 
-static char *RevMsg = "WCSHEAD WCSTools 3.8.5, 12 April 2012, Jessica Mink SAO";
+static char *RevMsg = "WCSHEAD WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
 
 int
 main (ac, av)
